==> haskell-chunked-data-0.2.0-13-armv7h.pkg.tar.xz: usr/share/haskell/haskell-chunked-data/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chunked-data
version: 0.2.0
id: chunked-data-0.2.0-4e0b1e7ec0ddce94d0cbc9c24739d039
key: chunk_Lqv5cYisONrEs2m2BVYMb2
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/chunked-data
synopsis: Typeclasses for dealing with various chunked data representations
description:
    Originally present in classy-prelude.
category: Data
author: Michael Snoyman
exposed: True
exposed-modules:
    Data.IOData Data.Textual.Encoding Data.Sequences.Lazy Data.Builder
    Data.ChunkedZip
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/chunked-data-0.2.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/chunked-data-0.2.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/chunked-data-0.2.0
hs-libraries: HSchunked-data-0.2.0-Lqv5cYisONrEs2m2BVYMb2
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    mono-traversable-0.10.1.1-444d89c530a7a69af62384c66ba2d700
    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock
haddock-html: /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chunked-data-0.2.0-15-armv7h.pkg.tar.xz: usr/share/haskell/haskell-chunked-data/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chunked-data
version: 0.2.0
id: chunked-data-0.2.0-0e06c4c78d0115de9d8c000bb08df0f5
key: chunk_6xPEbxfzN9G146uTUNE83W
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/chunked-data
synopsis: Typeclasses for dealing with various chunked data representations
description:
    Originally present in classy-prelude.
category: Data
author: Michael Snoyman
exposed: True
exposed-modules:
    Data.IOData Data.Textual.Encoding Data.Sequences.Lazy Data.Builder
    Data.ChunkedZip
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/chunked-data-0.2.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/chunked-data-0.2.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/chunked-data-0.2.0
hs-libraries: HSchunked-data-0.2.0-6xPEbxfzN9G146uTUNE83W
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    mono-traversable-0.10.1.1-7ac62162d55f8d714083ba886bfb5efd
    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock
haddock-html: /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
